@@ -2,21 +2,20 @@ from __future__ import absolute_import, division, print_function
 
 import json
 import logging
-import os
 import shlex
-import signal
 import subprocess
 from datetime import datetime
+from pathlib import Path
 from time import sleep
 
 import pytz
 import requests
 
 import satnogsclient.config
+import satnogsclient.radio.flowgraphs as flowgraphs
 from satnogsclient import settings
 from satnogsclient.observer.waterfall import plot_waterfall
 from satnogsclient.observer.worker import WorkerFreq, WorkerTrack
-from satnogsclient.upsat import gnuradio_handler
 
 try:
     from urllib.parse import urljoin
@@ -28,8 +27,6 @@ LOGGER = logging.getLogger(__name__)
 
 class Observer(object):
 
-    _gnu_proc = None
-
     # Variables from settings
     # Mainly present so we can support multiple ground stations from the client
 
@@ -43,19 +40,19 @@ class Observer(object):
         self.timestamp = None
         self.observation_end = None
         self.frequency = None
+        self.mode = None
+        self.baud = None
         self.observation_raw_file = None
         self.observation_ogg_file = None
         self.observation_waterfall_file = None
         self.observation_waterfall_png = None
         self.observation_receiving_decoded_data = None  # pylint: disable=C0103
         self.observation_decoded_data = None
-        self.baud = None
         self.observation_done_decoded_data = None
         self.tracker_freq = None
         self.tracker_rot = None
-        self.script_name = None
 
-    def setup(self, observation_id, tle, observation_end, frequency, baud, script_name):
+    def setup(self, observation_id, tle, observation_end, frequency, mode, baud):
         """
         Sets up required internal variables.
         * returns True if setup is ok
@@ -64,11 +61,11 @@ class Observer(object):
 
         # Set attributes
         self.observation_id = observation_id
-        self.script_name = script_name
         self.tle = tle
         self.observation_end = observation_end
         self.frequency = frequency
         self.baud = baud
+        self.mode = mode
 
         not_completed_prefix = 'receiving_satnogs'
         completed_prefix = 'satnogs'
@@ -115,13 +112,19 @@ class Observer(object):
         """Starts threads for rotcrl and rigctl."""
         if settings.SATNOGS_PRE_OBSERVATION_SCRIPT is not None:
             LOGGER.info('Executing pre-observation script.')
+
+            script_name = flowgraphs.SATNOGS_FLOWGRAPH_MODES[
+                flowgraphs.SATNOGS_FLOWGRAPH_MODE_DEFAULT]['script_name']
+            if self.mode in flowgraphs.SATNOGS_FLOWGRAPH_MODES:
+                script_name = flowgraphs.SATNOGS_FLOWGRAPH_MODES[self.mode]['script_name']
+
             replacements = [
-                ("{{FREQ}}", str(self.frequency)),
-                ("{{TLE}}", json.dumps(self.tle)),
-                ("{{TIMESTAMP}}", self.timestamp),
-                ("{{ID}}", str(self.observation_id)),
-                ("{{BAUD}}", str(self.baud)),
-                ("{{SCRIPT_NAME}}", self.script_name),
+                ('{{FREQ}}', str(self.frequency)),
+                ('{{TLE}}', json.dumps(self.tle)),
+                ('{{TIMESTAMP}}', self.timestamp),
+                ('{{ID}}', str(self.observation_id)),
+                ('{{BAUD}}', str(self.baud)),
+                ('{{SCRIPT_NAME}}', script_name),
             ]
             pre_script = []
             for arg in shlex.split(settings.SATNOGS_PRE_OBSERVATION_SCRIPT):
@@ -132,7 +135,7 @@ class Observer(object):
 
         # if it is APT we want to save with a prefix until the observation
         # is complete, then rename.
-        if settings.GNURADIO_APT_SCRIPT_FILENAME in self.script_name:
+        if self.mode == 'APT':
             self.observation_decoded_data =\
                  self.observation_receiving_decoded_data
 
@@ -144,20 +147,22 @@ class Observer(object):
         self.run_rig()
         sleep(1)
         LOGGER.info('Start gnuradio thread.')
-        self._gnu_proc = gnuradio_handler.exec_gnuradio(self.observation_raw_file,
-                                                        self.observation_waterfall_file,
-                                                        self.frequency, self.baud,
-                                                        self.script_name,
-                                                        self.observation_decoded_data)
+        flowgraph = satnogsclient.radio.flowgraphs.Flowgraph(
+            settings.SATNOGS_SOAPY_RX_DEVICE, settings.SATNOGS_RX_SAMP_RATE, self.frequency,
+            self.mode, self.baud, {
+                'audio': self.observation_raw_file,
+                'waterfall': self.observation_waterfall_file,
+                'decoded': self.observation_decoded_data
+            })
+        flowgraph.enabled = True
         # Polling gnuradio process status
-        self.poll_gnu_proc_status()
+        self.poll_gnu_proc_status(flowgraph)
 
-        if "satnogs_generic_iq_receiver.py" not in settings.GNURADIO_SCRIPT_FILENAME:
-            LOGGER.info('Rename encoded files for uploading.')
-            self.rename_ogg_file()
-            self.rename_data_file()
-            LOGGER.info('Creating waterfall plot.')
-            self.plot_waterfall()
+        # Rename files and create waterfall
+        self.rename_ogg_file()
+        self.rename_data_file()
+        LOGGER.info('Creating waterfall plot.')
+        self.plot_waterfall()
 
         # PUT client version and metadata
         base_url = urljoin(settings.SATNOGS_NETWORK_API_URL, 'observations/')
@@ -165,7 +170,7 @@ class Observer(object):
         url = urljoin(base_url, str(self.observation_id))
         if not url.endswith('/'):
             url += '/'
-        client_metadata = gnuradio_handler.get_gnuradio_info()
+        client_metadata = flowgraph.info
         client_metadata['latitude'] = settings.SATNOGS_STATION_LAT
         client_metadata['longitude'] = settings.SATNOGS_STATION_LON
         client_metadata['elevation'] = settings.SATNOGS_STATION_ELEV
@@ -181,24 +186,21 @@ class Observer(object):
                                 verify=settings.SATNOGS_VERIFY_SSL,
                                 stream=True,
                                 timeout=45)
+            resp.raise_for_status()
         except requests.exceptions.ConnectionError:
             LOGGER.error('%s: Connection Refused', url)
         except requests.exceptions.Timeout:
             LOGGER.error('%s: Connection Timeout - no metadata uploaded', url)
-        except requests.exceptions.RequestException as err:
-            LOGGER.error('%s: Unexpected error: %s', url, err)
-
-        try:
-            resp.raise_for_status()
         except requests.exceptions.HTTPError as http_error:
             LOGGER.error(http_error)
+        except requests.exceptions.RequestException as err:
+            LOGGER.error('%s: Unexpected error: %s', url, err)
 
     def run_rot(self):
         self.tracker_rot = WorkerTrack(ip=None,
                                        port=self.rot_port,
                                        frequency=self.frequency,
                                        time_to_stop=self.observation_end,
-                                       proc=self._gnu_proc,
                                        sleep_time=3)
         LOGGER.debug('TLE: %s', self.tle)
         LOGGER.debug('Observation end: %s', self.observation_end)
@@ -209,31 +211,35 @@ class Observer(object):
         self.tracker_freq = WorkerFreq(ip=self.rig_ip,
                                        port=self.rig_port,
                                        frequency=self.frequency,
-                                       time_to_stop=self.observation_end,
-                                       proc=self._gnu_proc)
+                                       time_to_stop=self.observation_end)
         LOGGER.debug('Rig Frequency %s', self.frequency)
         LOGGER.debug('Observation end: %s', self.observation_end)
         self.tracker_freq.trackobject(self.location, self.tle)
         self.tracker_freq.trackstart()
 
-    def poll_gnu_proc_status(self):
-        while self._gnu_proc.poll() is None and datetime.now(pytz.utc) <= self.observation_end:
+    def poll_gnu_proc_status(self, flowgraph):
+        while flowgraph.enabled and datetime.now(pytz.utc) <= self.observation_end:
             sleep(1)
+        flowgraph.enabled = False
         LOGGER.info('Tracking stopped.')
-        self._gnu_proc.send_signal(signal.SIGINT)
-        _, _ = self._gnu_proc.communicate()
         self.tracker_freq.trackstop()
         self.tracker_rot.trackstop()
         LOGGER.info('Observation Finished')
         LOGGER.info('Executing post-observation script.')
         if settings.SATNOGS_POST_OBSERVATION_SCRIPT is not None:
+
+            script_name = flowgraphs.SATNOGS_FLOWGRAPH_MODES[
+                flowgraphs.SATNOGS_FLOWGRAPH_MODE_DEFAULT]['script_name']
+            if self.mode in flowgraphs.SATNOGS_FLOWGRAPH_MODES:
+                script_name = flowgraphs.SATNOGS_FLOWGRAPH_MODES[self.mode]['script_name']
+
             replacements = [
-                ("{{FREQ}}", str(self.frequency)),
-                ("{{TLE}}", json.dumps(self.tle)),
-                ("{{TIMESTAMP}}", self.timestamp),
-                ("{{ID}}", str(self.observation_id)),
-                ("{{BAUD}}", str(self.baud)),
-                ("{{SCRIPT_NAME}}", self.script_name),
+                ('{{FREQ}}', str(self.frequency)),
+                ('{{TLE}}', json.dumps(self.tle)),
+                ('{{TIMESTAMP}}', self.timestamp),
+                ('{{ID}}', str(self.observation_id)),
+                ('{{BAUD}}', str(self.baud)),
+                ('{{SCRIPT_NAME}}', script_name),
             ]
             post_script = []
             for arg in shlex.split(settings.SATNOGS_POST_OBSERVATION_SCRIPT):
@@ -243,25 +249,29 @@ class Observer(object):
             subprocess.call(post_script)
 
     def rename_ogg_file(self):
-        if os.path.isfile(self.observation_raw_file):
-            os.rename(self.observation_raw_file, self.observation_ogg_file)
-        LOGGER.info('Rename encoded file for uploading finished')
+        observation_raw_file_path = Path(self.observation_raw_file)
+        if observation_raw_file_path.exists():
+            observation_raw_file_path.rename(Path(self.observation_ogg_file))
+            LOGGER.info('Rename encoded file for uploading finished')
 
     def rename_data_file(self):
-        if os.path.isfile(self.observation_receiving_decoded_data):
-            os.rename(self.observation_receiving_decoded_data, self.observation_done_decoded_data)
-        LOGGER.info('Rename data file for uploading finished')
+        observation_receiving_decoded_data_path = Path(self.observation_receiving_decoded_data)
+        if observation_receiving_decoded_data_path.exists():
+            observation_receiving_decoded_data_path.rename(Path(
+                self.observation_done_decoded_data))
+            LOGGER.info('Rename data file for uploading finished')
 
     def plot_waterfall(self):
-        if os.path.isfile(self.observation_waterfall_file):
+        try:
             plot_waterfall(waterfall_file=self.observation_waterfall_file,
                            waterfall_png=self.observation_waterfall_png)
-            if os.path.isfile(self.observation_waterfall_png) and \
-               settings.SATNOGS_REMOVE_RAW_FILES:
+            if settings.SATNOGS_REMOVE_RAW_FILES:
                 self.remove_waterfall_file()
-        else:
+        except FileNotFoundError:
             LOGGER.error('No waterfall data file found')
 
     def remove_waterfall_file(self):
-        if os.path.isfile(self.observation_waterfall_file):
-            os.remove(self.observation_waterfall_file)
+        try:
+            Path(self.observation_waterfall_file).unlink()
+        except FileNotFoundError:
+            LOGGER.error('Failed to remove waterfall file')
