@@ -12,7 +12,7 @@ import pytz
 
 from satnogsclient import settings
 from satnogsclient.observer.orbital import pinpoint
-from satnogsclient.radio import Radio
+from satnogsclient.rig import Rig
 from satnogsclient.rotator import Rotator
 
 LOGGER = logging.getLogger(__name__)
@@ -35,12 +35,11 @@ class Worker(object):
 
     _azimuth = None
     _altitude = None
-    _gnu_proc = None
 
     observer_dict = {}
     satellite_dict = {}
 
-    def __init__(self, ip, port, time_to_stop=None, frequency=None, proc=None, sleep_time=None):
+    def __init__(self, ip, port, time_to_stop=None, frequency=None, sleep_time=None):
         """Initialize worker class."""
         self._ip = ip
         self._port = port
@@ -48,8 +47,6 @@ class Worker(object):
             self._frequency = frequency
         if time_to_stop:
             self._observation_end = time_to_stop
-        if proc:
-            self._gnu_proc = proc
         if sleep_time:
             self._sleep_time = sleep_time
         self.track = None
@@ -137,18 +134,18 @@ class WorkerTrack(Worker):
         start -= timedelta(minutes=1)
 
         observer = ephem.Observer()
-        observer.lon = str(observer_dict["lon"])
-        observer.lat = str(observer_dict["lat"])
-        observer.elevation = observer_dict["elev"]
+        observer.lon = str(observer_dict['lon'])
+        observer.lat = str(observer_dict['lat'])
+        observer.elevation = observer_dict['elev']
         observer.date = ephem.Date(start)
 
-        satellite = ephem.readtle(str(satellite_dict["tle0"]), str(satellite_dict["tle1"]),
-                                  str(satellite_dict["tle2"]))
+        satellite = ephem.readtle(str(satellite_dict['tle0']), str(satellite_dict['tle1']),
+                                  str(satellite_dict['tle2']))
 
         timestamp_max = pytz.utc.localize(ephem.Date(observer.next_pass(satellite)[2]).datetime())
         pin = pinpoint(observer_dict, satellite_dict, timestamp_max)
-        azi_max = pin["az"].conjugate() * 180 / math.pi
-        alt_max = pin["alt"].conjugate() * 180 / math.pi
+        azi_max = pin['az'].conjugate() * 180 / math.pi
+        alt_max = pin['alt'].conjugate() * 180 / math.pi
 
         return (azi_max, alt_max, timestamp_max)
 
@@ -177,9 +174,9 @@ class WorkerTrack(Worker):
         if settings.SATNOGS_ROT_FLIP and settings.SATNOGS_ROT_FLIP_ANGLE:
             self._midpoint = WorkerTrack.find_midpoint(observer_dict, satellite_dict,
                                                        datetime.now(pytz.utc))
-            LOGGER.info("Antenna midpoint: AZ%.2f EL%.2f %s", *self._midpoint)
+            LOGGER.info('Antenna midpoint: AZ%.2f EL%.2f %s', *self._midpoint)
             self._flip = (self._midpoint[1] >= settings.SATNOGS_ROT_FLIP_ANGLE)
-            LOGGER.info("Antenna flip: %s", self._flip)
+            LOGGER.info('Antenna flip: %s', self._flip)
 
     def send_to_socket(self, pin, sock):
         # Read az/alt of sat and convert to degrees
@@ -209,18 +206,18 @@ class WorkerFreq(Worker):
         Uses observer and satellite objects set by trackobject().
         Will exit when observation_end timestamp is reached.
         """
-        radio = Radio(Hamlib.RIG_MODEL_NETRIGCTL, "{}:{}".format(self._ip, self._port))
-        radio.open()
+        rig = Rig(Hamlib.RIG_MODEL_NETRIGCTL, '{}:{}'.format(self._ip, self._port))
+        rig.open()
 
         # track satellite
         while self.is_alive:
 
             pin = pinpoint(self.observer_dict, self.satellite_dict)
             if pin['ok']:
-                self.send_to_socket(pin, radio)
+                self.send_to_socket(pin, rig)
                 time.sleep(self._sleep_time)
 
-        radio.close()
+        rig.close()
 
     def send_to_socket(self, pin, sock):
         doppler_calc_freq = self._frequency * (1 - (pin['rng_vlct'] / ephem.c))
