@@ -32,46 +32,19 @@ def spawn_observer(**kwargs):
         'lat': settings.SATNOGS_STATION_LAT,
         'elev': settings.SATNOGS_STATION_ELEV
     }
-    frequency = 100e6
+
     # Get the baudrate. In case of CW baudrate equals the WPM
     baud = 0
     if 'baud' in obj:
         baud = obj['baud']
-    frequency = obj['frequency']
-    script_name = settings.GNURADIO_SCRIPT_FILENAME
-    if 'mode' in obj and obj['mode']:
-        if obj['mode'] == "CW":
-            script_name = settings.GNURADIO_CW_SCRIPT_FILENAME
-        elif obj['mode'] == "APT":
-            script_name = settings.GNURADIO_APT_SCRIPT_FILENAME
-        elif obj['mode'].endswith('BPSK PMT-A3'):
-            script_name = settings.GNURADIO_ARGOS_BPSK_PMT_A3
-        elif obj['mode'].startswith('BPSK'):
-            script_name = settings.GNURADIO_BPSK_SCRIPT_FILENAME
-        elif obj['mode'] == 'GFSK Rktr':
-            script_name = settings.GNURADIO_GFSK_RKTR_SCRIPT_FILENAME
-        # FSK and MSK share the same flowgraph
-        elif (obj['mode'].startswith('FSK') or obj['mode'].startswith('GFSK')
-              or obj['mode'].startswith('MSK') or obj['mode'].startswith('GMSK')):
-            script_name = settings.GNURADIO_FSK_SCRIPT_FILENAME
-        elif obj['mode'].endswith('AFSK S-Net'):
-            script_name = settings.GNURADIO_AFSK_SNET_SCRIPT_FILENAME
-        elif obj['mode'].endswith('AFSK SALSAT'):
-            script_name = settings.GNURADIO_AFSK_SALSAT_SCRIPT_FILENAME
-        elif obj['mode'].endswith('AFSK1k2'):
-            script_name = settings.GNURADIO_AFSK1K2_SCRIPT_FILENAME
-        elif obj['mode'].endswith('DUV'):
-            script_name = settings.GNURADIO_AMSAT_DUV_SCRIPT_FILENAME
-        elif obj['mode'].endswith('SSTV'):
-            script_name = settings.GNURADIO_SSTV_SCRIPT_FILENAME
 
     setup_kwargs = {
         'observation_id': obj['id'],
         'tle': tle,
         'observation_end': end,
-        'frequency': frequency,
-        'baud': baud,
-        'script_name': script_name
+        'frequency': obj['frequency'],
+        'mode': obj['mode'],
+        'baud': baud
     }
 
     LOGGER.debug('Observer args: %s', setup_kwargs)
@@ -87,7 +60,7 @@ def spawn_observer(**kwargs):
 def keep_or_remove_file(filename):
     # If set, move uploaded file to `SATNOGS_COMPLETE_OUTPUT_PATH`,
     # otherwise delete it
-    if settings.SATNOGS_COMPLETE_OUTPUT_PATH != "":
+    if settings.SATNOGS_COMPLETE_OUTPUT_PATH != '':
         os.rename(os.path.join(settings.SATNOGS_OUTPUT_PATH, filename),
                   os.path.join(settings.SATNOGS_COMPLETE_OUTPUT_PATH, filename))
     else:
@@ -148,7 +121,7 @@ def post_data():
         except requests.exceptions.HTTPError:
             if response.status_code == 404:
                 LOGGER.error(
-                    'Upload of %s for observation %i failed, %s doesn\'t exist (404).'
+                    "Upload of %s for observation %i failed, %s doesn't exist (404)."
                     'Probably the observation was deleted.', fil, observation_id, url)
 
                 # Move file to `SATNOGS_INCOMPLETE_OUTPUT_PATH`
@@ -216,14 +189,12 @@ def status_listener():
     LOGGER.info('Starting scheduler...')
     SCHEDULER.start()
     SCHEDULER.remove_all_jobs()
-    interval = settings.SATNOGS_NETWORK_API_QUERY_INTERVAL
-    SCHEDULER.add_job(get_jobs, 'interval', minutes=interval)
-    msg = 'Registering `get_jobs` periodic task ({0} min. interval)'.format(interval)
-    LOGGER.info(msg)
-    interval = settings.SATNOGS_NETWORK_API_POST_INTERVAL
-    msg = 'Registering `post_data` periodic task ({0} min. interval)'.format(interval)
-    LOGGER.info(msg)
-    SCHEDULER.add_job(post_data, 'interval', minutes=interval)
+    LOGGER.info('Registering `get_jobs` periodic task (%d sec. interval)',
+                settings.SATNOGS_NETWORK_API_QUERY_INTERVAL)
+    SCHEDULER.add_job(get_jobs, 'interval', seconds=settings.SATNOGS_NETWORK_API_QUERY_INTERVAL)
+    LOGGER.info('Registering `post_data` periodic task (%d sec. interval)',
+                settings.SATNOGS_NETWORK_API_POST_INTERVAL)
+    SCHEDULER.add_job(post_data, 'interval', seconds=settings.SATNOGS_NETWORK_API_POST_INTERVAL)
 
 
 def get_observation_list():
